NAME
Logic::Relational::ArrayRest - Represents a rest/slurp wrapper for array unification.
SYNOPSIS
use Logic::Relational::ArrayRest;
my $rest = Logic::Relational::ArrayRest->new($variable);
DESCRIPTION
Logic::Relational::ArrayRest wraps a term to represent the rest of an array in unification. It is constructed using the rest or slurp DSL helpers.
METHODS
new
Constructor. Takes a single term (usually a variable).
term
Returns the wrapped term.
as_string
Returns the string representation of the wrapper.
freshen
Freshens the inner term, returning a new Logic::Relational::ArrayRest object.